The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Package {famnesia}


Title: Anonymising Familias Files
Version: 0.1.1
Description: A 'shiny' application for anonymising files exported from the 'Familias' software for forensic kinship analysis (Egeland et al. (2000) <doi:10.1016/s0379-0738(00)00147-x>). Pedigrees, marker data, allele frequencies and mutation models can be masked or modified, with options for preserving likelihood ratios exactly. The application is built on the 'pedsuite' packages for pedigree analysis.
License: GPL (≥ 3)
URL: https://magnusdv.shinyapps.io/famnesia/, https://github.com/magnusdv/famnesia
BugReports: https://github.com/magnusdv/famnesia/issues
Depends: R (≥ 4.4)
Imports: DT, bslib (≥ 0.11.0), htmltools, pedFamilias (≥ 0.2.6), pedmut, pedprobr (≥ 1.1.1), pedtools, shiny (≥ 1.9.0), shinyjs
Config/roxygen2/version: 8.1.0
Encoding: UTF-8
Language: en-GB
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-09-20 12:40:02 UTC; magnu
Author: Magnus Dehli Vigeland ORCID iD [aut, cre]
Maintainer: Magnus Dehli Vigeland <m.d.vigeland@medisin.uio.no>
Repository: CRAN
Date/Publication: 2026-10-02 09:20:08 UTC

famnesia: Anonymising Familias Files

Description

A 'shiny' application for anonymising files exported from the 'Familias' software for forensic kinship analysis. Pedigrees, marker data, allele frequencies and mutation models can be masked or modified, with options for preserving likelihood ratios exactly. The application is built on the 'pedsuite' packages for pedigree analysis.

Author(s)

Maintainer: Magnus Dehli Vigeland m.d.vigeland@medisin.uio.no (ORCID)

Authors:

See Also

Useful links:


Launch Famnesia

Description

This function launches the Famnesia Shiny application.

Usage

launchApp(launch.browser = TRUE, ...)

Arguments

launch.browser

Whether to launch the app in a browser. Default: TRUE.

...

Further arguments passed to shiny::runApp(), such as quiet, port and host

Value

The value returned by shiny::runApp()

Examples

if(interactive()) launchApp()

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.